@@ -1,5 +1,5 @@
 /*
-@version: 0.4
+@version: 0.5
 @author: Sudheer K. <scifi1947 at gmail.com>
 @license: GNU General Public License
 */
@@ -44,13 +44,11 @@ public:
 protected:
     void startCallStatusMonitors();
     QString convertToDTMFCode(QString);
-//    void connectToDBusSignals();
-//    void disconnectFromDBusSignals();
     bool isExcludedNumber(QString);
     bool placeCall(QString);
 
 protected slots:
-    QString callViaCallingCard();
+    QString callViaCallingCard(QString);
     void sendNumberAsDTMFCode(const QDBusMessage& dbusMessage);
     void stopCallStatusMonitors();
 
