@@ -110,7 +110,7 @@ bool DatabaseUtility::getAllProfiles(org::maemo::vicar::ProfileList* profileList
 bool DatabaseUtility::findProfileByNumber(QString number,org::maemo::vicar::Profile* profile){
     bool result = false;
     if (profilesDB.isOpen()){
-        QString strQuery = QString("select * from profiles where '%1' like numberpattern||'%' order by id")
+        QString strQuery = QString("select * from profiles where '%1' like numberpattern||'%' order by length(numberpattern) desc")
                            .arg(number);
         qDebug() << "SQL>"<<strQuery;
         QSqlQuery query(strQuery);
@@ -129,16 +129,24 @@ bool DatabaseUtility::findProfileByNumber(QString number,org::maemo::vicar::Prof
 
 int DatabaseUtility::insertProfile(org::maemo::vicar::Profile profile){
     int newId   = -1;
-    bool result = false;
+    bool result = false;    
     if (profilesDB.isOpen()){
-        QSqlQuery query;
-        QString strQuery = QString("insert into profiles values(NULL,'%1','%2','%3','%4','%5')")
-                           .arg(profile.phoneNumberPattern).arg(profile.gatewayNumber)
-                           .arg(profile.dtmfFormat).arg(profile.dtmfPrefix).arg(profile.dtmfSuffix);
-        qDebug() << "SQL>"<<strQuery;
-        result = query.exec(strQuery);
-        if (result){
-            newId = query.lastInsertId().toInt();
+        bool continueInsert = true;
+        if (!this->tableExists("profiles")){
+            continueInsert = this->createProfilesTable();
+        }
+
+        if (continueInsert)
+        {
+            QSqlQuery query;
+            QString strQuery = QString("insert into profiles values(NULL,'%1','%2','%3','%4','%5')")
+                               .arg(profile.phoneNumberPattern).arg(profile.gatewayNumber)
+                               .arg(profile.dtmfFormat).arg(profile.dtmfPrefix).arg(profile.dtmfSuffix);
+            qDebug() << "SQL>"<<strQuery;
+            result = query.exec(strQuery);
+            if (result){
+                newId = query.lastInsertId().toInt();
+            }
         }
     }
     return newId;
