@@ -22,7 +22,7 @@ protected:
 public:
     DbusUtility(QObject * parent = 0);
     ~DbusUtility();
-    QDBusConnection getConnection();
+    QDBusConnection getConnection(bool systemBus = true);
     void setConnection(QDBusConnection connection);
     bool sendSignal(QString strPath,QString strInterface,QString strName);
     bool sendMethodCall(QString strService,QString strPath,
