@@ -15,6 +15,8 @@
 #define AM_SERVICE          "org.freedesktop.Telepathy.AccountManager"
 #define AM_OBJ_PATH         "/org/freedesktop/Telepathy/AccountManager"
 #define AM_INTERFACE        "org.freedesktop.Telepathy.AccountManager"
+#define RING_CONN_SERVICE   "org.freedesktop.Telepathy.Connection.ring.tel.ring"
+#define RING_CONN_PATH      "/org/freedesktop/Telepathy/Connection/ring/tel/ring"
 #define DBUS_SERVICE        "org.freedesktop.DBus.Properties"
 #define DBUS_OBJ_PATH       "/org/freedesktop/DBus/Properties"
 #define DBUS_PROPS_IFACE     "org.freedesktop.DBus.Properties"
@@ -53,6 +55,8 @@ public:
     bool accountExists();
     bool createAccount();
     bool deleteAccount();
+    bool callNumberWithRing(QString number);
+    bool sendDTMFTone(QString tone);
 };
 
 #endif // TELEPATHYUTILITY_H
